# Copyright (c) 2022 DisplayLink (UK) Ltd.
import PyEvdi
import os

_FullHDAreaLimit = 1920*1080
_4KAreaLimit = 3840*2160
_60Hz=60

def is_not_running_as_root():
    return os.geteuid() != 0

def get_available_evdi_card():
    for i in range(20):
        if PyEvdi.check_device(i) == PyEvdi.AVAILABLE:
            return i
    PyEvdi.add_device()
    for i in range(20):
        if PyEvdi.check_device(i) == PyEvdi.AVAILABLE:
            return i
    return -1

def get_edid():
    edid_file = os.path.join(os.path.dirname(os.path.dirname(__file__)), "sample_edid", "4K60HzTest.edid")
    with open(edid_file, mode='rb') as file:
        ed = file.read()
    return ed



# Copyright (c) 2022 DisplayLink (UK) Ltd.
import PyEvdi
import pytest
import os
import utilities

@pytest.mark.skipif(utilities.get_available_evdi_card() == -1 , reason = 'No available device.')
@pytest.mark.skipif(utilities.get_available_evdi_card() == -1 and utilities.is_not_running_as_root(), reason = 'Please run test as root.')
def testOpeningNewCard():
    x = PyEvdi.Card(utilities.get_available_evdi_card())
    assert x

@pytest.mark.skipif(utilities.get_available_evdi_card() == -1 , reason = 'No available device.')
@pytest.mark.skipif(utilities.get_available_evdi_card() == -1 and utilities.is_not_running_as_root(), reason = 'Please run test as root.')
def testOpeningAndClosingNewCard():
    x = PyEvdi.Card(utilities.get_available_evdi_card())
    x.close()
    assert x

def testOpeningInvalidCard():    
    with pytest.raises(ValueError):
        PyEvdi.Card(44)



import pytest
import PyEvdi
import utilities


@pytest.mark.skipif(utilities.get_available_evdi_card() == -1, reason = 'No available device.')
@pytest.mark.skipif(utilities.get_available_evdi_card() == -1 and utilities.is_not_running_as_root(), reason = 'Please run test as root.')
def testEnablingCursorEventsWithoutCursorSetHandlers(caplog):
    card = PyEvdi.Card(utilities.get_available_evdi_card())
    edid = utilities.get_edid()
    card.connect(edid, len(edid), utilities._FullHDAreaLimit, utilities._FullHDAreaLimit * utilities._60Hz)

    assert "Enabling cursor events on" not in caplog.text
    card.enableCursorEvents(True)
    assert "Enabling cursor events on" in caplog.text

    card.disconnect()
    card.close()

@pytest.mark.skipif(utilities.get_available_evdi_card() == -1, reason = 'No available device.')
@pytest.mark.skipif(utilities.get_available_evdi_card() == -1 and utilities.is_not_running_as_root(), reason = 'Please run test as root.')
def testDisablingCursorEventsDoesNotShowEnablingCursorEventsMsgInLog(caplog):
    card = PyEvdi.Card(utilities.get_available_evdi_card())
    edid = utilities.get_edid()
    card.connect(edid, len(edid), utilities._FullHDAreaLimit, utilities._FullHDAreaLimit * utilities._60Hz)


    card.enableCursorEvents(False)
    assert "Enabling cursor events on" not in caplog.text

    card.disconnect()
    card.close()
